/*
 * This module was prepared by Abi Sarvepalli, Christopher Jensen, and Zheng Zhang at the Dorrestein
 * Lab (University of California, San Diego).
 * 
 * It is freely available under the GNU GPL licence of MZmine2.
 * 
 * For any questions or concerns, please refer to:
 * https://groups.google.com/forum/#!forum/molecular_networking_bug_reports
 * 
 * Credit to the Du-Lab development team for the initial commitment to the MGF export module.
 */

package io.github.mzmine.modules.io.siriusexport;

import java.awt.*;

import io.github.mzmine.modules.tools.msmsspectramerge.MsMsSpectraMergeParameters;
import io.github.mzmine.parameters.Parameter;
import io.github.mzmine.parameters.dialogs.ParameterSetupDialog;
import io.github.mzmine.parameters.impl.SimpleParameterSet;
import io.github.mzmine.parameters.parametertypes.MassListParameter;
import io.github.mzmine.parameters.parametertypes.filenames.FileNameParameter;
import io.github.mzmine.parameters.parametertypes.selectors.PeakListsParameter;
import io.github.mzmine.parameters.parametertypes.submodules.OptionalModuleParameter;
import io.github.mzmine.util.ExitCode;

public class SiriusExportParameters extends SimpleParameterSet {

    public static final OptionalModuleParameter<MsMsSpectraMergeParameters> MERGE_PARAMETER = new OptionalModuleParameter<>(
            "Merge MS/MS",
            "Merge high qualitative MS/MS into one spectrum instead of exporting all MS/MS separately.",
            new MsMsSpectraMergeParameters(), true);

    public SiriusExportParameters() {
        super(new Parameter[] { PEAK_LISTS, MASS_LIST, FILENAME,
                MERGE_PARAMETER });
    }

    public static final PeakListsParameter PEAK_LISTS = new PeakListsParameter();

    public static final FileNameParameter FILENAME = new FileNameParameter(
            "Filename",
            "Name of the output MGF file. "
                    + "Use pattern \"{}\" in the file name to substitute with feature list name. "
                    + "(i.e. \"blah{}blah.mgf\" would become \"blahSourcePeakListNameblah.mgf\"). "
                    + "If the file already exists, it will be overwritten.",
            "mgf");

    // public static final BooleanParameter FRACTIONAL_MZ = new
    // BooleanParameter(
    // "Fractional m/z values", "If checked, write fractional m/z values",
    // true);

    /*
     * public static final BooleanParameter INCLUDE_MSSCAN = new
     * BooleanParameter( "include MS1",
     * "For each MS/MS scan include also the corresponding MS scan (additionally to possibly detected isotope patterns). MS1 scans might contain valuable informations that can be processed by SIRIUS. But they increase file size significantly"
     * , true );
     */

    public static final MassListParameter MASS_LIST = new MassListParameter();

    public ExitCode showSetupDialog(Window parent, boolean valueCheckRequired) {
        String message = "<html>SIRIUS Module Disclaimer:" + "<ul>"
                + "<li>If you use the SIRIUS export module, cite <a href=\"https://bmcbioinformatics.biomedcentral.com/articles/10.1186/1471-2105-11-395\">MZmine2 paper</a> and the following article:<br>"
                + "<a href=\"http://dx.doi.org/10.1038/s41592-019-0344-8\">K. Duhrkop, et al., Sirius 4: a rapid tool for turning tandem mass spectra into metabolite structure information, Nature Methods, 2019.</a>"
                + "<li>Sirius can be downloaded at the following address: <a href=\"https://bio.informatik.uni-jena.de/software/sirius/\">https://bio.informatik.uni-jena.de/software/sirius/</a>"
                + "<li>Sirius results can be mapped into <a href=\"http://gnps.ucsd.edu/\">GNPS</a> molecular networks. <a href=\"https://bix-lab.ucsd.edu/display/Public/Mass+spectrometry+data+pre-processing+for+GNPS\">See the documentation</a>."
                + "</ul>";
        ParameterSetupDialog dialog = new ParameterSetupDialog(parent,
                valueCheckRequired, this, message);
        dialog.setVisible(true);
        return dialog.getExitCode();
    }
}
